"""XKNX is a Python 3 library for KNX/IP protocol."""
# flake8: noqa
from .xknx import XKNX

__all__ = [
    "XKNX",
]
